@@ -52,7 +52,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
     if len(validated_date_list) == 0:
         print("Cannot find logs file around {}".format(date_in_study))
-        return None
+        return df_logs_combined
 
     for date in validated_date_list:
         date_folder_path = intermediate_participant_path + sep + date
@@ -60,11 +60,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
 
         csv_path = csv_path_list[0]
 
-        try:
-            df_day = pd.read_csv(csv_path)
-        except AttributeError:
-            print("AttributeError (phone lock) : " + csv_path)
-            quit()
+        df_day = pd.read_csv(csv_path)
 
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
@@ -175,8 +171,12 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
     # Read, parse and combine related intermediate file
     df_logs_combined = combine_intermediate_file(intermediate_participant_path, date_in_study)
 
-    # Match the combined parsed intermediate file with prompt feature data frame
-    phone_lock_column, last_usage_column  = match_feature(prompt_local_datetime_series, df_logs_combined)
+    if df_logs_combined.shape[0] > 0:
+        # Match the combined parsed intermediate file with prompt feature data frame
+        phone_lock_column, last_usage_column  = match_feature(prompt_local_datetime_series, df_logs_combined)
+    else:
+        phone_lock_column = ["NF"] * len(prompt_local_datetime_series)
+        last_usage_column = ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     # result_column_transformed = transform(result_column)
